from setuptools import setup, find_packages

setup(
    name='proyectoFinal',
    version='1.1',
    author='iduarte',
    description='pg2 TTS  Irving Duarte',
    author_email='irving.duarte@outlook.com',
    packages=find_packages(),
)
